
<?php
/*
Plugin Name: Always display Eventbrite tickets iFrame
Description: Overrides the iFrame HTML code to try and show it anyway.
Version: 0.1.0
Author: Modern Tribe
Author URI: https://theeventscalendar.com
*/

/**
 * Overrides the Eventbrite ticket iFrame HTML to show it no matter the event status.
 *
 * There is no guarantee that the iFrame displayed will be correct but it allows us to work-around
 * a possible malfunction.
 *
 * @param string $html     The current iFrame HTML.
 * @param string $event_id associated Eventbrite ID.
 * @param int    $post_id  The current event post ID.
 *
 * @return string The original HTML if no change was required or the modified HTML.
 */
function eb_override_ticket_iframe_html( $html, $event_id, $post_id ) {
    // Since it's working by itself let's let the plugin do its work.
    if ( ! empty( $html ) ) {
        return $html;
    }

    // Extra safety: let's not show it if the current user cannot read it.
    $post_type = get_post_type_object( get_post_type( $post_id ) );
    $read_post = $post_type->cap->read_post;

    if ( ! current_user_can( $read_post ) ) {
        return $html;
    }

     // Here we just rebuild the iFrame HTML to display it ignoring the checks, it's a copy&paste from the plugin code.
    $iframe_url = 'https://www.eventbrite.com/tickets-external?eid=%s&amp;ref=etckt&v=2';
    $iframe_url = apply_filters( 'tribe_events_eb_iframe_url', sprintf( $iframe_url, $event_id ) );
    // here we're really guessing but it's a good assumption that most events will have 1 ticket assigned.
    $num_visible_tickets = 1;
    $iframe_height       = 166 + ( $num_visible_tickets * 103 );

    $html = sprintf(
        '<div class="eventbrite-ticket-embed">
                        <iframe id="eventbrite-tickets-%1$s" src="%2$s" height="%3$s" width="100%%" frameborder="0" allowtransparency="true"></iframe>
                        <div style="font-family:Helvetica, Arial, sans-serif; font-size:12px;margin:2px 0; width:100%; text-align:left;" >
                            <a class="eventbrite-powered-by-eb" style="color: #ADB0B6; text-decoration: none;" target="_blank" rel="noopener" href="http://www.eventbrite.com/">Powered by Eventbrite</a>
                        </div>
                    </div>',
        $event_id,
        $iframe_url,
        $iframe_height
    );

    return $html;
}

add_filter( 'tribe_events_eb_iframe_html', 'eb_override_ticket_iframe_html', 10, 3 );
